LemniskFlutter class

An implementation of FlutterWrapperPlatform that uses method channels.

Inheritance

Constructors

LemniskFlutter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

onNotificationTapped Stream<Map<String, dynamic>>
no setter

Static Methods

clearContext() Future<void>
Clears any context previously set via setContext.
dispose() → void
identify(String userId, Map<String, dynamic>? properties, [Map<String, dynamic>? otherIds]) Future<void>
init({required String writeKeyAndroid, required String writeKeyIOS, required String serverUrl, String? consentUrl, String? notificationCenterUrl, bool? enablePush, bool? enablePullNotifications, bool? enableAnalytics, bool? enableInApp, bool? enableDebugMode}) Future<void>
Runtime init (backward-compat / consent-gated / white-label path).
isInitialized() Future<bool>
Returns whether the native SDK has finished initializing.
pauseInApp() Future<void>
Pauses in-app campaign evaluation/display.
registerForPushNotifications(String? title, String? message) Future<Map<String, dynamic>>
resumeInApp() Future<void>
Resumes in-app campaign evaluation/display after a pauseInApp call.
screen(String name, Map<String, dynamic>? properties, [Map<String, dynamic>? otherIds]) Future<void>
setContext(String context) Future<void>
Sets the current in-app context (e.g. the active screen/section tab).
setDeviceIdToWebview(String domain) Future<void>
track(String eventName, Map<String, dynamic>? properties, [Map<String, dynamic>? otherIds]) Future<void>

Constants

methodChannel → const MethodChannel
The method channel used to interact with the native platform.